@@ -1,3 +1,21 @@
+# Permission is hereby granted, free of charge, to any person obtaining
+# a copy of this software and associated documentation files (the
+# "Software"), to deal in the Software without restriction, including
+# without limitation the rights to use, copy, modify, merge, publish,
+# distribute, sublicense, and/or sell copies of the Software, and to
+# permit persons to whom the Software is furnished to do so, subject to
+# the following conditions:
+#
+# The above copyright notice and this permission notice shall be included
+# in all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """Formats docstrings to follow PEP 257."""
 
 import re
@@ -8,7 +26,7 @@ except ImportError:
     from io import StringIO
 
 
-__version__ = '0.2.4'
+__version__ = '0.2.5'
 
 
 def format_code(source,
@@ -155,7 +173,7 @@ def split_summary_and_description(contents):
         return (split[0], '\n'.join(split[1:]))
     else:
         # Break on first sentence.
-        split = re.split('\.\s', string=contents, maxsplit=1)
+        split = re.split(r'\.\s', string=contents, maxsplit=1)
         if len(split) == 2:
             return (split[0].strip() + '.', split[1].strip())
         else:
@@ -175,7 +193,7 @@ def strip_docstring(docstring):
 def normalize_summary(summary):
     """Return normalized docstring summary."""
     # Remove newlines
-    summary = re.sub('\s*\n\s*', ' ', summary.rstrip())
+    summary = re.sub(r'\s*\n\s*', ' ', summary.rstrip())
 
     # Add period at end of sentence
     if summary and summary[-1].isalnum():
@@ -232,8 +250,6 @@ def main(argv, standard_out):
     parser = argparse.ArgumentParser(description=__doc__, prog='docformatter')
     parser.add_argument('--in-place', action='store_true',
                         help='make changes to files instead of printing diffs')
-    parser.add_argument('--no-backup', dest='backup', action='store_false',
-                        help='do not write backup files')
     parser.add_argument(
         '--wrap-long-summaries', default=0, type=int, metavar='LENGTH',
         help='wrap long summary lines at this length (default: %(default)s)')
@@ -262,12 +278,6 @@ def main(argv, standard_out):
 
         if source != formatted_source:
             if args.in_place:
-                # Write output files with same encoding as input
-                if args.backup:
-                    with open_with_encoding(filename + '.backup', mode='w',
-                                            encoding=encoding) as backup_file:
-                        backup_file.write(source)
-
                 with open_with_encoding(filename, mode='w',
                                         encoding=encoding) as output_file:
                     output_file.write(formatted_source)
